The following individuals have contributed code to agate-mdb:

* `Loïc Corbasson <https://github.com/lcorbasson>`_

Some code was inspired by contributions or ideas by:

* `John B. Nelson <https://github.com/jbn/>`_
